@@ -7,10 +7,11 @@ use strict;
 
 package XML::Compile::SOAP::HTTPClient;
 use vars '$VERSION';
-$VERSION = '0.58';
+$VERSION = '0.59';
 use base 'XML::Compile::SOAP::Client';
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
+use XML::Compile::SOAP::Util qw/SOAP11ENV/;
 
 use LWP            ();
 use LWP::UserAgent ();
@@ -23,7 +24,7 @@ use XML::LibXML   ();
 my $parser = XML::LibXML->new;
 
 # (Microsofts HTTP Extension Framework)
-my $http_ext_id = 'http://schemas.xmlsoap.org/soap/envelope/';
+my $http_ext_id = SOAP11ENV;
 
 
 sub new(@)
